@@ -4,13 +4,13 @@ from dg_sdk.core.rsa_utils import rsa_long_encrypt
 
 class Card(object):
     """
-    证件
+    银行卡片对象
     """
     card_id = ""  # 卡号
-    card_name = ""  # 卡姓名
-    card_mp = ""  # 个人证件有效期类型
-    vip_code = ""  # 个人证件有效期起始日
-    expiration = ""  # 个人证件有效期到期日，长期有效不填
+    card_name = ""  # 卡户姓名
+    card_mp = ""  # 卡片手机号
+    vip_code = ""  # 卡片安全码
+    expiration = ""  # 卡片有效期
 
     def __init__(self, card_id, card_name, card_mp, vip_code="", expiration=""):
         self.card_id = rsa_long_encrypt(card_id, DGClient.mer_config.public_key)
