@@ -4,7 +4,7 @@ from dg_sdk.core.rsa_utils import rsa_long_encrypt
 
 class Cert(object):
     """
-    证件
+    证件对象
     """
     cert_type = ""  # 证件类型
     cert_id = ""  # 证件ID
