@@ -6,7 +6,6 @@ from tests.conftest import *
 class TestRequestTools(unittest.TestCase):
 
     def setUp(self):
-        dg_sdk.DGClient.init_log(console_enable=True, log_level=20)
         dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key, public_key, sys_id, product_id, huifu_id)
 
         print("setup")
@@ -17,7 +16,7 @@ class TestRequestTools(unittest.TestCase):
     def test_request_post(self):
         request_params = {
             "trade_type": "A_NATIVE",
-            "trans_amt": "0.01",
+            "trans_amt": "0.01","："""
             "goods_desc": "goods_desc"
         }
         result = dg_sdk.request_post("https://api.huifu.com/v2/trade/payment/jspay", request_params)
